==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/CadToolMatrix/ts/CadToolMatrix_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CadToolMatrix</name>
    <message>
        <location filename="../CadToolMatrix.js" line="+366"/>
        <source>Expand all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Collapse all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+48"/>
        <source>Tool Matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>List view</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolMatrixWidget</name>
    <message>
        <location filename="../CadToolMatrix.ui" line="+37"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/CadToolMatrix/ts/CadToolMatrix_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CadToolMatrix</name>
    <message>
        <location filename="../CadToolMatrix.js" line="+373"/>
        <source>Expand all</source>
        <translation>Rozwiń wszystko</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Collapse all</source>
        <translation>Zwiń wszystko</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>List View</source>
        <translation>Widok listy</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Icon View</source>
        <translation>Widok ikon</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Widgets</source>
        <translation>Widżety</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+48"/>
        <source>Tool Matrix</source>
        <translation>Tabela narzędzi</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Rozmiar ikon:</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Pixel</source>
        <translation>piksele</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>piks.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>List view</source>
        <translation>Widok listy</translation>
    </message>
</context>
<context>
    <name>ToolMatrixWidget</name>
    <message>
        <location filename="../CadToolMatrix.ui" line="+37"/>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
</context>
</TS>
